@@ -7,14 +7,20 @@ setClass("SPEARMAN",
 
 setValidity("SPEARMAN", function(object){
   if(object@p.opt == "table")
-    stop('No "table" option for SPEARMAN, please use "MC" or "table".')
+    stop('No "table" option for SPEARMAN, please use "MC" or "dist".')
+
 })
 
 
 setMethod("test", signature(object = "SPEARMAN"), function(object){
   p = object@pdata
   n = nrow(p[[ls(p)]])
+  if(length(unique(p[[ls(p)]][,1])) != n || length(unique(p[[ls(p)]][,2])) != n)
+    stop("Ties detected. Spearman cannot handle tie.")
+
   out = cor.test(p[[ls(p)]][,1], p[[ls(p)]][,2], method = "spearman")
+
+
   #Test Statistic
   rho = out$estimate
   t = rho*sqrt((n-2)/(1-rho^2))
@@ -29,7 +35,8 @@ setMethod("test", signature(object = "SPEARMAN"), function(object){
     for(i in 1:sn){
       if(object@set.seed){set.seed(i)}
       sim = data.frame(cbind(rnorm(n,0,1), rnorm(n,0,1)))
-      ts[i] = cor.test(sim[,1], sim[,2], method = "spearman")$estimate
+      rhos = cor.test(sim[,1], sim[,2], method = "spearman")$estimate
+      ts[i] = rhos*sqrt((n-2)/(1-rhos^2))
     }
     NGE = length(which(ts>t))
     NLE = sn-NGE
